yt.utilities.lib.alt\_ray\_tracers module
=========================================

.. automodule:: yt.utilities.lib.alt_ray_tracers
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
